firebase_create_test_token

package module
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 26, 2021 License: MIT Imports: 7 Imported by: 0

README

Firebase Create Test Token

Create a custom token for a specific UID and simply verify it using the Firebase API.

func CreateTestToken(client *auth.Client, firebaseKey, uid string) (string, error)

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateTestToken

func CreateTestToken(client *auth.Client, firebaseKey, uid string) (string, error)

CreateTestToken creates a custom token for the specified UID and verifies it with the Firebase API

Types

This section is empty.

Jump to